==> ejc-ztjpoc-api-3.0.0-20210416.005022-6-sources.jar: com/ejianc/poc/vo/WorkAuthVO.java <==
package com.ejianc.poc.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 工作授权表
 * 
 * @author generator
 * 
 */
public class WorkAuthVO extends BaseVO {
	private static final long serialVersionUID = 1L;

	private Integer targetType; // 授权对象类型  1 人员 2 岗位
	private String targetId; // 授权对象ID
	private String targetName;//授权对象名称
	private String providerId; // 授权对象所在二级单位id

	private String corpPk; // 授权对象授权范围组织id


	private String orgId; // 授权对象 是人员时候是人员主岗位，是岗位时候是岗位上级
	private String orgName;//授权对象所属组织名称，根据orgId向上查询的名称拼接，去掉虚拟组织

	/**
	 * 授权对象类型
	 */
	public Integer getTargetType() {
		return targetType;
	}

	/**
	 * 授权对象类型
	 */
	public void setTargetType(Integer targetType) {
		this.targetType = targetType;
	}

	/**
	 * 授权对象ID
	 */
	public String getTargetId() {
		return targetId;
	}

	/**
	 * 授权对象ID
	 */
	public void setTargetId(String targetId) {
		this.targetId = targetId;
	}

	/**
	 * 公司pk
	 */
	public String getCorpPk() {
		return corpPk;
	}

	/**
	 * 公司pk
	 */
	public void setCorpPk(String corpPk) {
		this.corpPk = corpPk;
	}

	/**
	 * 组织id
	 */
	public String getOrgId() {
		return orgId;
	}

	/**
	 * 组织id
	 */
	public void setOrgId(String orgId) {
		this.orgId = orgId;
	}

	public String getTargetName() {
		return targetName;
	}

	public void setTargetName(String targetName) {
		this.targetName = targetName;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public String getProviderId() {
		return providerId;
	}

	public void setProviderId(String providerId) {
		this.providerId = providerId;
	}
}

==> ejc-ztjpoc-api-3.0.0-20210420.093128-9-sources.jar: com/ejianc/poc/vo/WorkAuthVO.java <==
package com.ejianc.poc.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 工作授权表
 * 
 * @author generator
 * 
 */
public class WorkAuthVO extends BaseVO {
	private static final long serialVersionUID = 1L;

	private Integer targetType; // 授权对象类型  1 人员 2 岗位
	private String targetId; // 授权对象ID
	private String targetName;//授权对象名称
	private String providerId; // 授权对象所在二级单位id

	private String corpPk; // 授权对象授权范围组织id
	private String corpProviderId; // 授权对象授权范围组织所在二级单位id

	private String orgId; // 授权对象 是人员时候是人员主岗位，是岗位时候是岗位上级
	private String orgName;//授权对象所属组织名称，根据orgId向上查询的名称拼接，去掉虚拟组织

	/**
	 * 授权对象类型
	 */
	public Integer getTargetType() {
		return targetType;
	}

	/**
	 * 授权对象类型
	 */
	public void setTargetType(Integer targetType) {
		this.targetType = targetType;
	}

	/**
	 * 授权对象ID
	 */
	public String getTargetId() {
		return targetId;
	}

	/**
	 * 授权对象ID
	 */
	public void setTargetId(String targetId) {
		this.targetId = targetId;
	}

	/**
	 * 公司pk
	 */
	public String getCorpPk() {
		return corpPk;
	}

	/**
	 * 公司pk
	 */
	public void setCorpPk(String corpPk) {
		this.corpPk = corpPk;
	}

	/**
	 * 组织id
	 */
	public String getOrgId() {
		return orgId;
	}

	/**
	 * 组织id
	 */
	public void setOrgId(String orgId) {
		this.orgId = orgId;
	}

	public String getTargetName() {
		return targetName;
	}

	public void setTargetName(String targetName) {
		this.targetName = targetName;
	}

	public String getOrgName() {
		return orgName;
	}

	public void setOrgName(String orgName) {
		this.orgName = orgName;
	}

	public String getProviderId() {
		return providerId;
	}

	public void setProviderId(String providerId) {
		this.providerId = providerId;
	}

	public String getCorpProviderId() {
		return corpProviderId;
	}

	public void setCorpProviderId(String corpProviderId) {
		this.corpProviderId = corpProviderId;
	}
}
